# Searching and Filtering in the Inventory
### On this page
  * [Introduction](https://help.sap.com/docs/leanix/ea/searching-and-filtering-in-inventory#introduction)
  * [Searching and Filtering](https://help.sap.com/docs/leanix/ea/searching-and-filtering-in-inventory#searching-and-filtering)
  * [Searching and Applying Filters](https://help.sap.com/docs/leanix/ea/searching-and-filtering-in-inventory#searching-and-applying-filters)
  * [Searching and Filtering Using Natural Language](https://help.sap.com/docs/leanix/ea/searching-and-filtering-in-inventory#searching-and-filtering-using-natural-language)
  * [Applying Filters From the Filter Panel](https://help.sap.com/docs/leanix/ea/searching-and-filtering-in-inventory#applying-filters-from-the-filter-panel)
  * [Searching for Filter Groups](https://help.sap.com/docs/leanix/ea/searching-and-filtering-in-inventory#searching-for-filter-groups)
  * [Displaying and Hiding Filters](https://help.sap.com/docs/leanix/ea/searching-and-filtering-in-inventory#displaying-and-hiding-filters)
  * [Saving Search Results](https://help.sap.com/docs/leanix/ea/searching-and-filtering-in-inventory#saving-search-results)
  * [Viewing Filtered Fact Sheets in Reports](https://help.sap.com/docs/leanix/ea/searching-and-filtering-in-inventory#viewing-filtered-fact-sheets-in-reports)


Searching and filtering in the inventory helps efficiently manage your data. Learn how to quickly find fact sheets, apply filters, manage filters, and save search results for future access.
